Most Apparent Distortion (MAD)
==============================

.. automodule:: viqa.fr_metrics.mad
    :exclude-members: MAD, most_apparent_distortion, most_apparent_distortion_3d

   
.. rubric:: Functions

.. currentmodule:: viqa.fr_metrics.mad

.. autosummary::
    :toctree: generated/

      most_apparent_distortion
      most_apparent_distortion_3d


.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.mad

.. autosummary::
    :toctree: generated/
    :template: class.rst

    MAD